@@ -7,15 +7,16 @@ import os
 abstract = abc.abstractmethod
 
 from clu.constants.consts import ENCODING, PYTHON_VERSION
+from clu.abstract import Slotted
 from clu.config.base import Flat, Nested
 from clu.config.fieldtypes import FieldBase
-from clu.fs.misc import stringify
 from clu.predicates import (haspyattr, getpyattr,
                             stattr, pyattrs,
                             always, no_op,
                             iscontainer, slots_for)
+from clu.repr import stringify
 from clu.typology import differentlength, ismapping, isstring
-from clu.exporting import Slotted, Exporter
+from clu.exporting import Exporter
 
 exporter = Exporter(path=__file__)
 export = exporter.decorator()
@@ -411,6 +412,7 @@ def test():
     from clu.config.formats import JsonFile
     from clu.fs.filesystem import TemporaryName
     from clu.repl.ansi import print_separator, print_ansi_centered, ANSIFormat
+    from clu.testing.utils import inline
     from pprint import pprint
     
     nullformat = ANSIFormat.null()
@@ -432,6 +434,7 @@ def test():
             youlike = fields.String("you like:")
             andalso = fields.Tuple(value=fields.String("«also»", allow_none=False))
     
+    @inline
     def test_one():
         
         instance = MySchema()
@@ -513,6 +516,7 @@ def test():
         print()
         # print_separator()
     
+    @inline
     def test_two():
         print_separator(filler='•')
         print_ansi_centered("TEST TWO", color=nullformat)
