@@ -25,7 +25,7 @@ except ImportError:
     importlib.metadata = _metadata
 
 from clu.constants.consts import PROJECT_NAME, QUALIFIER, NoDefault
-from clu.predicates import attr, attr_search, mro, typeof, newtype, union
+from clu.predicates import attr, attr_search, mro, typeof, newtype
 from clu.naming import nameof, dotpath_split, dotpath_join
 from clu.typespace import Namespace, types
 from clu.typology import isstring, subclasscheck
@@ -62,7 +62,7 @@ class MetaRegistry(clu.abstract.NonSlotted):
     
     @staticmethod
     def for_appname(appname):
-        """ Return the module with the qualified registered module name """
+        """ Return the weak-value dictionary of classes for the registered appname """
         if not appname:
             raise ValueError("appname required")
         if not isstring(appname):
@@ -214,7 +214,7 @@ class FinderBase(clu.abstract.AppName, importlib.abc.MetaPathFinder):
     def invalidate_caches(cls):
         cls.loader.create_module.cache_clear()
         cls.cache.clear()
-        return super(FinderBase, cls).invalidate_caches(cls())
+        return None
     
     @classmethod
     def iter_modules(cls):
@@ -478,7 +478,7 @@ class ModuleBase(Package, Registry, metaclass=MetaModule):
             An “__execute__()” method should not accept any arguments or return
             any values. The “self” instance it receives will be fully initialized
             and include “appname”, “appspace”, ‘name’, ‘prefix’, ‘qualname’,
-            and other PEP-451-related module attributes.
+            as well as all of the PEP-451-related module attributes.
             
             Currently, the base class implementation is a no-op – but should
             class-based module authors write their own “__execute__()” methods,
@@ -504,9 +504,9 @@ class ModuleBase(Package, Registry, metaclass=MetaModule):
         cls = type(self)
         if hasattr(cls, 'exporter'):
             return cls.exporter.dir_function()()
-        names = union(cls.__dict__.keys(),
+        names = chain(cls.__dict__.keys(),
                       super(ModuleBase, self).__dir__())
-        return sorted(list(names - DO_NOT_INCLUDE))
+        return sorted(frozenset(names) - DO_NOT_INCLUDE)
 
 def installed_appnames():
     """ Return a set of the appnames for all installed finders
