@@ -76,8 +76,7 @@ class TestAbstractMetas(object):
         # Ensure “sys.path” contains the “yodogg” package:
         prefix = dirname.subdirectory('yodogg')
         assert prefix.exists
-        pypath.remove_invalid_paths()  # cleans “sys.path”
-        pypath.append_paths(prefix)    # extends “sys.path”
+        pypath.enhance(prefix)
         
         class AppConfigBase(abc.ABC, metaclass=clu.abstract.Prefix):
             pass
