@@ -22,8 +22,7 @@ class TestExporting(object):
         # Ensure “sys.path” contains the “yodogg” package:
         prefix = dirname.subdirectory('yodogg')
         assert prefix.exists
-        pypath.remove_invalid_paths()  # cleans “sys.path”
-        pypath.append_paths(prefix)    # extends “sys.path”
+        pypath.enhance(prefix)
         
         # Bring in the package-specific ExporterBase subclass,
         # as well as the module-local instance of that subclass,
