@@ -6,10 +6,29 @@ import pytest
 from clu.constants import consts
 from clu.constants.exceptions import Nondeterminism
 
+yo_dogg_rename = lambda: print("Yo dogg.")
+i_heard_rename = lambda *wat: print("I heard you like %s" % ", ".join(repr(w) for w in wat))
+
 class TestNaming(object):
     
     """ Run the tests for the clu.naming module. """
     
+    def test_renamer(self):
+        from clu.naming import rename
+        from clu.predicates import pyname
+        fake_dotpath = 'yodogg.iheard'
+        
+        renamer = rename(dotpath=fake_dotpath)
+        
+        # yo_dogg = lambda: print("Yo dogg.")
+        # i_heard = lambda *wat: print("I heard you like %s" % ", ".join(repr(w) for w in wat))
+        
+        yo_dogg = renamer(yo_dogg_rename)
+        i_heard = renamer(i_heard_rename)
+        
+        assert pyname(yo_dogg) == pyname(yo_dogg_rename) == 'yo_dogg_rename'
+        assert pyname(i_heard) == pyname(i_heard_rename) == 'i_heard_rename'
+    
     def test_module_inspectors_0(self):
         from clu.naming import isbuiltin
         
@@ -82,7 +101,7 @@ class TestNaming(object):
     
     @pytest.mark.skipif(consts.PYPY, reason="Failure on PyPy")
     @pytest.mark.nondeterministic
-    def _test_qualified_name_constants(self):
+    def test_qualified_name_constants(self):
         """ » Checking “qualified_name(¬) on items from clu.constants …” """
         from clu.constants.consts import (BASEPATH, HOSTNAME, VERBOTEN, SCRIPT_PATH, TEST_PATH)
         from clu.naming import qualified_name
